package mi.hdm;

import mi.hdm.mealPlan.MealPlan;
import mi.hdm.recipes.CategoryManager;
import mi.hdm.recipes.IngredientManager;
import mi.hdm.recipes.RecipeManager;
import mi.hdm.shoppingList.ShoppingList;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 * This class contains all the services in the application: recipe manager, ingredient manager, shopping list,
 * category manager and meal plan.
 */
public class TastyPages {
    private final RecipeManager recipeManager;
    private final IngredientManager ingredientManager;
    private final ShoppingList shoppingList;
    private final CategoryManager categoryManager;
    private final MealPlan mealPlan;

    private final static Logger log = LogManager.getLogger(TastyPages.class);

    /**
     * Creates a new instance of the application holding all user data. The parameters are expected to be parsed with the FileManager
     */
    public TastyPages(RecipeManager recipeManager, IngredientManager ingredientManager, CategoryManager categoryManager, MealPlan mealPlan, ShoppingList shoppingList) {
        this.recipeManager = recipeManager;
        this.ingredientManager = ingredientManager;
        this.categoryManager = categoryManager;
        this.mealPlan = mealPlan;
        this.shoppingList = shoppingList;
        log.info("Loaded TastyPages with all dependencies.");
    }

    public TastyPages(IngredientManager ingredientManager) {
        this.ingredientManager = ingredientManager;
        this.recipeManager = new RecipeManager();
        this.categoryManager = new CategoryManager();
        this.mealPlan = new MealPlan(recipeManager);
        this.shoppingList = new ShoppingList(recipeManager);
        log.info("Loaded TastyPages with ingredient manager");
    }

    /**
     * Creates a new, completely empty instance of the application. This constructor is not expected to be used.
     */
    public TastyPages() {
        this.recipeManager = new RecipeManager();
        this.ingredientManager = new IngredientManager();
        this.categoryManager = new CategoryManager();
        this.mealPlan = new MealPlan(recipeManager);
        this.shoppingList = new ShoppingList(recipeManager);
        log.info("Created empty instance of TastyPages");
    }

    public RecipeManager getRecipeManager() {
        return recipeManager;
    }

    public IngredientManager getIngredientManager() {
        return ingredientManager;
    }

    public ShoppingList getShoppingList() {
        return shoppingList;
    }

    public CategoryManager getCategoryManager() {
        return categoryManager;
    }

    public MealPlan getMealPlan() {
        return mealPlan;
    }
}
